import React from 'react';

import { Wrapper } from './styled';

const properties: {[index: string]: string} = {
  m: 'margin',
  p: 'padding',
  d: 'display',
  jc: 'justify-content',
  a: 'align-items',
  fd: 'flex-direction',
};

const directions: {[index: string]: string} = {
  t: 'Top',
  r: 'Right',
  b: 'Bottom',
  l: 'Left',
};

type Props = {
  [index: string]: React.ReactNode;
  children: React.ReactNode;
};

const Box: React.FunctionComponent<Props> = ({
  children,
  ...rest
}: Props) => {
  const args = Object.keys(rest);

  const styles = args.map((ele: string) => {
    const property = properties[ele[0]];
    const direction = directions[ele[1]];
    if (direction) {
      return `${property}-${direction}: ${rest[ele]}px;`;
    }
    return `${property}: ${rest[ele]};`;
  });

  return (
    <Wrapper
      styles={styles}
    >
      {children}
    </Wrapper>
  );
};

export default Box;
